# The DisplayLang fork of SymPy

[SymPy](https://github.com/sympy/sympy) is a computer algebra system written
entirely in Python. It is a powerful library, and an excellent open-source
project.

This is a fork of SymPy that uses
[`DisplayLang`](https://github.com/proofscape/displaylang) for parsing
expressions.

The intention is to keep up with the latest version of SymPy, while maintaining
this difference.

## Versioning

This project is starting out at major version 0. This is consistent with a new
project, in which there is not yet any commitment to backwards compatibility.

The intention is to keep the minor version equal to the latest minor version of
SymPy.

The patch version will vary independently of that of SymPy. It will encompass
patches merged from SymPy, plus patches and features unique to this project.
